fnss.traffic.eventscheduling.poisson_process_event_schedule — FNSS 0.1.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »

# fnss.traffic.eventscheduling.poisson_process_event_schedule

`poisson_process_event_schedule`(avg_interval, t_start, duration, t_unit, event_generator, *args, **kwargs)

  Return a schedule of Poisson-distributed events

  Parameters : | avg_interval : float The average time interval between subsequent events t_start : float The time at which the schedule starts duration : float The duration of the event schedule t_unit: string : The unit in which time values are expressed (e.g. ‘ms’, ‘s’) event_generator : function A function that when called returns an event, i.e. a dictionary of event properties *args : argument list List of non-keyworded arguments for event_generator function **kwargs : keyworded argument list List of keyworded arguments for event_generator function Returns : ——- : event_schedule : EventSchedule An EventSchedule object

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »